@@ -15,7 +15,7 @@ from PlanetProfile.GetConfig import Params as configParams, FigMisc
 from PlanetProfile.MagneticInduction.MagneticInduction import MagneticInduction, ReloadInduction, Benm2absBexyz
 from PlanetProfile.MagneticInduction.Moments import InductionResults, Excitations as Mag
 from PlanetProfile.Plotting.ProfilePlots import GeneratePlots, PlotInductOgram, \
-    PlotInductOgramPhaseSpace, PlotExploreOgram, PlotComplexBdip
+    PlotInductOgramPhaseSpace, PlotExploreOgram, PlotComplexBdip, PlotMagSpectrum
 from PlanetProfile.Thermodynamics.LayerPropagators import IceLayers, OceanLayers, InnerLayers
 from PlanetProfile.Thermodynamics.Electrical import ElecConduct
 from PlanetProfile.Thermodynamics.Seismic import SeismicCalcs
@@ -150,8 +150,11 @@ def run(bodyname=None, opt=None, fNames=None):
             Params.FigureFiles = FigureFilesSubstruct(comparePath, compareBase, FigMisc.xtn)
             GeneratePlots(CompareList, Params)
 
-            if Params.PLOT_BDIP and Params.CALC_CONDUCT and not Params.SKIP_INDUCTION:
-                PlotComplexBdip(CompareList, Params)
+            if Params.CALC_CONDUCT and not Params.SKIP_INDUCTION:
+                if Params.PLOT_BDIP:
+                    PlotComplexBdip(CompareList, Params)
+                if Params.PLOT_MAG_SPECTRUM and np.any([Planet.Magnetic.FT_LOADED for Planet in CompareList]):
+                    PlotMagSpectrum(CompareList, Params)
 
         # Print table outputs
         if Params.DISP_LAYERS or Params.DISP_TABLE:
@@ -201,9 +204,13 @@ def PlanetProfile(Planet, Params):
         Planet, Params = MagneticInduction(Planet, Params)
 
         # Plot induced dipole surface strength
-        if ((not Params.SKIP_PLOTS) and Params.PLOT_BDIP and Planet.Do.VALID) and \
+        if ((not Params.SKIP_PLOTS) and Planet.Do.VALID) and \
             not (Params.DO_INDUCTOGRAM or Params.DO_EXPLOREOGRAM):
-            PlotComplexBdip(np.array([Planet]), Params)
+            if Params.PLOT_BDIP:
+                PlotComplexBdip(np.array([Planet]), Params)
+
+            if Params.PLOT_MAG_SPECTRUM and Planet.Magnetic.FT_LOADED:
+                PlotMagSpectrum([Planet], Params)
 
     PrintCompletion(Planet, Params)
     return Planet, Params
@@ -837,9 +844,14 @@ def ReloadInductOgram(bodyname, Params, fNameOverride=None):
             bodydir = bodyname
         Planet = importlib.import_module(f'{bodydir}.PP{loadname}InductOgram').Planet
         Params.DataFiles, Params.FigureFiles = SetupFilenames(Planet, Params)
-        reload = loadmat(Params.DataFiles.inductOgramFile)
+        loadFile = Params.DataFiles.inductOgramFile
     else:
-        reload = loadmat(fNameOverride)
+        loadFile = fNameOverride
+    if os.path.isfile(loadFile):
+        reload = loadmat(loadFile)
+    else:
+        raise FileNotFoundError(f'Attempted to reload inductogram, but {loadFile} was not found. ' +
+                                'Re-run with Params.CALC_NEW_INDUCT = True in configPP.py.')
 
     Induction = InductionResults
     Induction.bodyname = reload['bodyname'][0]
