@@ -15,6 +15,7 @@ from PlanetProfile.Thermodynamics.HydroEOS import GetPhaseIndices
 from PlanetProfile.Thermodynamics.InnerEOS import GetInnerEOS
 from PlanetProfile.Utilities.SetupInit import SetupFilenames
 from PlanetProfile.Utilities.defineStructs import Constants
+from PlanetProfile.MagneticInduction.Moments import Excitations
 
 # Assign logger
 log = logging.getLogger('PlanetProfile')
@@ -1107,7 +1108,7 @@ def PlotInductOgram(Induction, Params):
 
         for z, name, fLabel in zip(comboData, comboTitles, comboLabels):
             ax = axes[coords[fLabel]]
-            ax.title.set_text(name)
+            ax.set_title(name)
             zContours = [ax.contour(Induction.sigmaMean_Sm, Induction.D_km, z[i, ...],
                            colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                            linewidths=Style.LW_Induction[T], levels=IndParams.GetClevels(fLabel, T))
@@ -1117,6 +1118,9 @@ def PlotInductOgram(Induction, Params):
                            fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                            for i, T in enumerate(Induction.Texc_hr.keys())]
 
+        if FigMisc.PLOT_V2021 and Induction.bodyname in ['Europa', 'Ganymede', 'Callisto']:
+            AddV2021points(Params.Induct, Induction.bodyname, 'sigma', allAxes)
+
         if Params.LEGEND:
             lines = np.array([contour.legend_elements()[0][0] for contour in zContours])
             axes[1,1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
@@ -1149,7 +1153,7 @@ def PlotInductOgram(Induction, Params):
 
             for z, name, fLabel in zip(comboData, comboTitles, comboLabels):
                 ax = axes[coords[fLabel]]
-                ax.title.set_text(name)
+                ax.set_title(name)
                 zContours = [ax.contour(Induction.x, Induction.y, z[i, ...],
                                         colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                                         linewidths=Style.LW_Induction[T],
@@ -1159,6 +1163,9 @@ def PlotInductOgram(Induction, Params):
                            fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                            for i, T in enumerate(Induction.Texc_hr.keys())]
 
+            if FigMisc.PLOT_V2021 and Induction.bodyname in ['Europa', 'Ganymede', 'Callisto']:
+                AddV2021points(Params.Induct, Induction.bodyname, Params.Induct.inductOtype, allAxes)
+
             if Params.LEGEND:
                 lines = np.array([contour.legend_elements()[0][0] for contour in zContours])
                 axes[1,1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
@@ -1191,10 +1198,10 @@ def PlotInductOgram(Induction, Params):
             [ax.set_xlim(FigLbl.sigLims) for ax in axes[1,:]]
             [ax.set_ylim(FigLbl.Dlims) for ax in axes[1,:]]
 
-            axes[0,0].title.set_text(comboTitles[0])
-            axes[1,0].title.set_text(comboTitles[0])
-            axes[0,1].title.set_text(comboTitles[-1])
-            axes[1,1].title.set_text(comboTitles[-1])
+            axes[0,0].set_title(comboTitles[0])
+            axes[1,0].set_title(comboTitles[0])
+            axes[0,1].set_title(comboTitles[-1])
+            axes[1,1].set_title(comboTitles[-1])
             zContours = [axes[0,0].contour(Induction.x, Induction.y, comboData[0][i, ...],
                                     colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                                     linewidths=Style.LW_Induction[T],
@@ -1222,6 +1229,10 @@ def PlotInductOgram(Induction, Params):
                        fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                        for i, T in enumerate(Induction.Texc_hr.keys())]
 
+            if FigMisc.PLOT_V2021 and Induction.bodyname in ['Europa', 'Ganymede', 'Callisto']:
+                AddV2021points(Params.Induct, Induction.bodyname, Params.Induct.inductOtype, axes[0,:])
+                AddV2021points(Params.Induct, Induction.bodyname, 'sigma', axes[1,:])
+
             if Params.LEGEND:
                 lines = np.array([contour.legend_elements()[0][0] for contour in zContours])
                 axes[1,1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
@@ -1249,8 +1260,8 @@ def PlotInductOgram(Induction, Params):
 
         # Labels and titles
         fig.suptitle(FigLbl.inductionTitle)
-        axes[0].title.set_text(name)
-        axes[1].title.set_text(FigLbl.phaseTitle)
+        axes[0].set_title(name)
+        axes[1].set_title(FigLbl.phaseTitle)
         [ax.set_xlabel(FigLbl.sigMeanLabel) for ax in axes]
         [ax.set_ylabel(FigLbl.Dlabel) for ax in axes]
         [ax.set_xlim(FigLbl.sigLims) for ax in axes]
@@ -1277,6 +1288,9 @@ def PlotInductOgram(Induction, Params):
         else:
             fNameSigma = Params.FigureFiles.sigma[fLabel]
 
+        if FigMisc.PLOT_V2021 and Induction.bodyname in ['Europa', 'Ganymede', 'Callisto']:
+            AddV2021points(Params.Induct, Induction.bodyname, 'sigma', axes)
+
         if Params.LEGEND:
             lines = np.array([contour.legend_elements()[0][0] for contour in phaseContours])
             axes[1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
@@ -1296,8 +1310,8 @@ def PlotInductOgram(Induction, Params):
 
             # Labels and titles
             fig.suptitle(FigLbl.inductionTitle)
-            axes[0].title.set_text(name)
-            axes[1].title.set_text(FigLbl.phaseTitle)
+            axes[0].set_title(name)
+            axes[1].set_title(FigLbl.phaseTitle)
             [ax.set_xscale(FigLbl.wScale) for ax in axes]
             [ax.set_xlabel(FigLbl.wLabel) for ax in axes]
             [ax.set_ylabel(FigLbl.yLabelInduct) for ax in axes]
@@ -1318,6 +1332,9 @@ def PlotInductOgram(Induction, Params):
                             fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                             for i, T in enumerate(Induction.Texc_hr.keys())]
 
+            if FigMisc.PLOT_V2021 and Induction.bodyname in ['Europa', 'Ganymede', 'Callisto']:
+                AddV2021points(Params.Induct, Induction.bodyname, Params.Induct.inductOtype, axes)
+
             if Params.LEGEND:
                 lines = np.array([contour.legend_elements()[0][0] for contour in phaseContours])
                 axes[1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
@@ -1330,6 +1347,32 @@ def PlotInductOgram(Induction, Params):
     return
 
 
+def AddV2021points(IndParams, bodyname, inductOtype, axes):
+    if inductOtype == 'sigma' or inductOtype == 'Tb':
+        log.debug('Adding Vance et al. (2021) markers to inductogram.')
+        if inductOtype == 'sigma':
+            xVals = IndParams.V2021_sigma_Sm[bodyname]
+            yVals = IndParams.V2021_D_km[bodyname]
+        else:
+            xVals = IndParams.V2021_w_ppt[bodyname]
+            yVals = IndParams.V2021_Tb_K[bodyname]
+        UP = IndParams.V2021_zb_km[bodyname] == np.min(IndParams.V2021_zb_km[bodyname])
+        DOWN = np.logical_not(UP)
+        [ax.scatter(xVals[UP], yVals[UP], marker=IndParams.V2021_MS[bodyname][UP][0],
+                    facecolor=IndParams.V2021_FC[bodyname][UP],
+                    edgecolor=IndParams.V2021_EC[bodyname][UP],
+                    label=r'Vance et al.\ (2021) models') for ax in axes]
+        [ax.scatter(xVals[DOWN], yVals[DOWN], marker=IndParams.V2021_MS[bodyname][DOWN][0],
+                    facecolor=IndParams.V2021_FC[bodyname][DOWN],
+                    edgecolor=IndParams.V2021_EC[bodyname][DOWN]
+                    ) for ax in axes]
+    else:
+        log.warning(f'FigMisc.PLOT_V2021 is True but inductOtype "{inductOtype}" is '
+                    'not supported. Skipping.')
+
+    return
+
+
 def PlotExploreOgram(ExplorationList, Params):
     """ For plotting points showing the various models used in making
         exploreogram plots.
@@ -1617,3 +1660,88 @@ def PlotComplexBdip(PlanetList, Params):
                 plt.close()
 
     return
+
+
+def PlotMagSpectrum(PlanetList, Params):
+    """ Plot Fourier spectra of magnetic excitations, complex response
+        amplitude, and induced dipole components.
+    """
+
+    axComps = ['x', 'y', 'z']
+    # Get first entry in PlanetList for which FT_LOADED is True
+    if PlanetList[0].Magnetic.FT_LOADED:
+        mainPlanet = PlanetList[0]
+    else:
+        mainPlanet = next(Planet for Planet in PlanetList if Planet.Magnetic.FT_LOADED)
+
+    # Create figure
+    fig = plt.figure(figsize=FigSize.MagFT)
+    grid = GridSpec(3, 1)
+    axes = np.array([fig.add_subplot(grid[i, 0]) for i in range(3)])
+    if Style.GRIDS:
+        [ax.grid() for ax in axes]
+        [ax.set_axisbelow(True) for ax in axes]
+
+    # Labels and titles
+    if Params.MagSpectrum.Tmin_hr is None:
+        Tmin_hr = np.min(mainPlanet.Magnetic.TexcFT_hr)
+    else:
+        Tmin_hr = Params.MagSpectrum.Tmin_hr
+    Tmax_hr = np.minimum(np.max(mainPlanet.Magnetic.TexcFT_hr), mainPlanet.Magnetic.TmaxFT_hr)
+    Texc_hr = np.array(list(Excitations.Texc_hr[mainPlanet.bodyname].values()), dtype=np.float_)
+    Texc_hr = Texc_hr[np.isfinite(Texc_hr)]
+    if FigMisc.MAG_SPECTRA_PERIODS:
+        freqLabel = FigLbl.TexcLabel
+        freqVar = mainPlanet.Magnetic.TexcFT_hr
+        freqLims = [Tmin_hr, Tmax_hr]
+        mainExc = np.sort(Texc_hr)
+    else:
+        freqLabel = FigLbl.fExcLabel
+        freqVar = 1 / mainPlanet.Magnetic.TexcFT_hr / 3600
+        freqLims = [1 / Tmax_hr / 3600, 1 / Tmin_hr / 3600]
+        mainExc = np.sort(1 / Texc_hr / 3600)
+    [ax.set_xlim(freqLims) for ax in axes]
+    [ax.set_xlabel(freqLabel) for ax in axes]
+    [ax.set_xscale('log') for ax in axes]
+    axes[1].set_ylim([0, 1])
+    axes[0].set_ylabel(FigLbl.BeFTlabel)
+    axes[1].set_ylabel(FigLbl.Ae1FTlabel)
+    axes[2].set_ylabel(FigLbl.BiFTlabel)
+    axes[0].set_title(FigLbl.BeFTtitle)
+    axes[1].set_title(FigLbl.Ae1FTtitle)
+    axes[2].set_title(FigLbl.BiFTtitle)
+    [ax.set_yscale('log') for ax in [axes[0], axes[2]]]
+    if mainPlanet.Magnetic.coordTypeFT is not None:
+        FTtitle = f'{mainPlanet.name} {FigLbl.MagFTtitle}, {mainPlanet.Magnetic.coordTypeFT} coordinates'
+    else:
+        FTtitle = f'{mainPlanet.name} {FigLbl.MagFTtitle}'
+    fig.suptitle(FTtitle)
+
+    # Plot the data
+    [axes[0].plot(freqVar, np.abs(mainPlanet.Magnetic.Be1xyzFT_nT[vComp]), label=f'$B^e_{vComp}$',
+                  color=Color.BeiFT[vComp], linestyle=Style.LS_FT, linewidth=Style.LW_FT) for vComp in axComps]
+    [axes[2].plot(freqVar, np.abs(mainPlanet.Magnetic.Bi1xyzFT_nT[vComp]), label=f'$B^i_{vComp}$',
+                  color=Color.BeiFT[vComp], linestyle=Style.LS_FT, linewidth=Style.LW_FT) for vComp in axComps]
+    if np.size(PlanetList) > 1 and Params.COMPARE:
+        # Only plot comparisons on amplitude plot
+        [axes[1].plot(freqVar, np.abs(Planet.Magnetic.Ae1FT), label=Planet.label,
+                      color=Color.Ae1FT, linestyle=Style.LS_FT, linewidth=Style.LW_FT) 
+         for Planet in PlanetList if Planet.Magnetic.FT_LOADED and Planet.bodyname == mainPlanet.bodyname]
+    else:
+        axes[1].plot(freqVar, np.abs(mainPlanet.Magnetic.Ae1FT), label=r'$\mathcal{A}^e_1$',
+                      color=Color.Ae1FT, linestyle=Style.LS_FT, linewidth=Style.LW_FT)
+    if FigMisc.MARK_TEXC:
+        axes[1].plot([mainExc[0], mainExc[0]], [0, 1], label=r'Dominant $T_\mathrm{exc}$',
+                     color=Color.TexcFT, linestyle=Style.LS_TexcFT, linewidth=Style.LW_TexcFT)
+        [axes[1].plot([Tmark, Tmark], [0, 1], color=Color.TexcFT, linestyle=Style.LS_TexcFT, 
+                      linewidth=Style.LW_TexcFT) for Tmark in mainExc[1:]]
+
+    if Params.LEGEND:
+        [ax.legend() for ax in axes]
+
+    plt.tight_layout()
+    fig.savefig(Params.FigureFiles.MagFT, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+    log.debug(f'Magnetic Fourier spectra plot saved to file: {Params.FigureFiles.MagFT}')
+    plt.close()
+
+    return
