@@ -1,10 +1,13 @@
 import os
 import numpy as np
-import logging as log
+import logging
 from scipy.interpolate import RectBivariateSpline, interp1d as Interp1D, griddata as GridData
 from PlanetProfile import _ROOT
 from PlanetProfile.Utilities.defineStructs import Constants, EOSlist
 
+# Assign logger
+log = logging.getLogger('PlanetProfile')
+
 def GetInnerEOS(EOSfname, EOSinterpMethod='nearest', nHeaders=13, Fe_EOS=False, kThermConst_WmK=None,
                 HtidalConst_Wm3=0, porosType=None, phiTop_frac=0, Pclosure_MPa=350, phiMin_frac=None,
                 EXTRAP=False):
@@ -17,7 +20,14 @@ def GetInnerEOS(EOSfname, EOSinterpMethod='nearest', nHeaders=13, Fe_EOS=False,
         log.debug(f'{innerEOS.comp} EOS already loaded. Reusing existing EOS.')
         innerEOS = EOSlist.loaded[innerEOS.EOSlabel]
 
-    return innerEOS
+    # Ensure each EOSlabel is included in EOSlist, in case we have reused EOSs with
+    # e.g. a smaller range that can reuse the larger-range already-loaded EOS.
+    if innerEOS.EOSlabel not in EOSlist.loaded.keys():
+        EOSlist.loaded[innerEOS.EOSlabel] = innerEOS
+
+    innerEOSwrapper = EOSwrapper(innerEOS.EOSlabel)
+
+    return innerEOSwrapper
 
 class PerplexEOSStruct:
     """ Loads in Perple_X table and creates interpolators that can be called to
@@ -46,6 +56,7 @@ class PerplexEOSStruct:
             self.fpath = os.path.join(self.dir, EOSfname)
             self.Fe_EOS = Fe_EOS
             self.EXTRAP = EXTRAP
+            self.EOStype = 'inner'
             self.porosType = porosType
             self.phiTop_frac = phiTop_frac
             self.Pclosure_MPa = Pclosure_MPa
@@ -53,7 +64,7 @@ class PerplexEOSStruct:
 
             if self.fpath in EOSlist.loaded.keys():
                 log.debug('Reloading previously imported Perplex table.')
-                self.P_MPa, self.T_K, self.ufn_rho_kgm3, self.ufn_VP_kms, self.ufn_VS_kms, \
+                P_MPa, T_K, self.ufn_rho_kgm3, self.ufn_VP_kms, self.ufn_VS_kms, \
                 self.ufn_KS_GPa, self.ufn_GS_GPa, self.ufn_Cp_JkgK, self.ufn_alpha_pK \
                     = EOSlist.loaded[self.fpath]
                 self.Pmin, self.Pmax, self.Tmin, self.Tmax, self.deltaP, self.deltaT \
@@ -143,36 +154,36 @@ class PerplexEOSStruct:
                 if np.any(np.isnan(GS_bar)): raise RuntimeError(errNaNstart + 'GS' + errNaNend)
 
                 # Now make 2D grids of values.
-                self.rho_kgm3 = np.reshape(rho_kgm3, (-1,dim2))
-                self.VP_kms = np.reshape(VP_kms, (-1,dim2))
-                self.VS_kms = np.reshape(VS_kms, (-1,dim2))
-                self.Cp_JkgK = np.reshape(Cp_Jm3K, (-1,dim2)) / self.rho_kgm3
-                self.alpha_pK = np.reshape(alpha_pK, (-1,dim2))
-                self.KS_GPa = np.reshape(KS_bar, (-1,dim2)) * Constants.bar2GPa
-                self.GS_GPa = np.reshape(GS_bar, (-1,dim2)) * Constants.bar2GPa
+                rho_kgm3 = np.reshape(rho_kgm3, (-1,dim2))
+                VP_kms = np.reshape(VP_kms, (-1,dim2))
+                VS_kms = np.reshape(VS_kms, (-1,dim2))
+                Cp_JkgK = np.reshape(Cp_Jm3K, (-1,dim2)) / rho_kgm3
+                alpha_pK = np.reshape(alpha_pK, (-1,dim2))
+                KS_GPa = np.reshape(KS_bar, (-1,dim2)) * Constants.bar2GPa
+                GS_GPa = np.reshape(GS_bar, (-1,dim2)) * Constants.bar2GPa
 
                 if P_FIRST:
                     # Transpose 2D meshes if P is the first column.
-                    self.rho_kgm3 = self.rho_kgm3.T
-                    self.VP_kms = self.VP_kms.T
-                    self.VS_kms = self.VS_kms.T
-                    self.Cp_JkgK = self.Cp_JkgK.T
-                    self.alpha_pK = self.alpha_pK.T
-                    self.KS_GPa = self.KS_GPa.T
-                    self.GS_GPa = self.GS_GPa.T
+                    rho_kgm3 = rho_kgm3.T
+                    VP_kms = VP_kms.T
+                    VS_kms = VS_kms.T
+                    Cp_JkgK = Cp_JkgK.T
+                    alpha_pK = alpha_pK.T
+                    KS_GPa = KS_GPa.T
+                    GS_GPa = GS_GPa.T
 
-                self.P_MPa = P1D_MPa
-                self.T_K = T1D_K
+                P_MPa = P1D_MPa
+                T_K = T1D_K
                 # Assign temporary functions we will wrap with porosity if modeled
-                self.ufn_rho_kgm3 = RectBivariateSpline(P1D_MPa, T1D_K, self.rho_kgm3)
-                self.ufn_VP_kms = RectBivariateSpline(P1D_MPa, T1D_K, self.VP_kms)
-                self.ufn_VS_kms = RectBivariateSpline(P1D_MPa, T1D_K, self.VS_kms)
-                self.ufn_KS_GPa = RectBivariateSpline(P1D_MPa, T1D_K, self.KS_GPa)
-                self.ufn_GS_GPa = RectBivariateSpline(P1D_MPa, T1D_K, self.GS_GPa)
-                self.ufn_Cp_JkgK = RectBivariateSpline(P1D_MPa, T1D_K, self.Cp_JkgK)
-                self.ufn_alpha_pK = RectBivariateSpline(P1D_MPa, T1D_K, self.alpha_pK)
+                self.ufn_rho_kgm3 = RectBivariateSpline(P1D_MPa, T1D_K, rho_kgm3)
+                self.ufn_VP_kms = RectBivariateSpline(P1D_MPa, T1D_K, VP_kms)
+                self.ufn_VS_kms = RectBivariateSpline(P1D_MPa, T1D_K, VS_kms)
+                self.ufn_KS_GPa = RectBivariateSpline(P1D_MPa, T1D_K, KS_GPa)
+                self.ufn_GS_GPa = RectBivariateSpline(P1D_MPa, T1D_K, GS_GPa)
+                self.ufn_Cp_JkgK = RectBivariateSpline(P1D_MPa, T1D_K, Cp_JkgK)
+                self.ufn_alpha_pK = RectBivariateSpline(P1D_MPa, T1D_K, alpha_pK)
 
-                EOSlist.loaded[self.fpath] = (self.P_MPa, self.T_K, self.ufn_rho_kgm3, self.ufn_VP_kms, self.ufn_VS_kms,
+                EOSlist.loaded[self.fpath] = (P_MPa, T_K, self.ufn_rho_kgm3, self.ufn_VP_kms, self.ufn_VS_kms,
                                               self.ufn_KS_GPa, self.ufn_GS_GPa, self.ufn_Cp_JkgK, self.ufn_alpha_pK)
                 EOSlist.ranges[self.fpath] = (self.Pmin, self.Pmax, self.Tmin, self.Tmax, self.deltaP, self.deltaT)
 
@@ -186,22 +197,22 @@ class PerplexEOSStruct:
                     kThermConst_WmK = Constants.kThermFe_WmK
                 else:
                     kThermConst_WmK = Constants.kThermSil_WmK
-            self.kTherm_WmK = np.zeros((np.size(self.P_MPa), np.size(self.T_K))) + kThermConst_WmK  # Placeholder until a self-consistent determination is implemented
-            self.ufn_kTherm_WmK = RectBivariateSpline(self.P_MPa, self.T_K, self.kTherm_WmK)
+            kTherm_WmK = np.zeros((np.size(P_MPa), np.size(T_K))) + kThermConst_WmK  # Placeholder until a self-consistent determination is implemented
+            self.ufn_kTherm_WmK = RectBivariateSpline(P_MPa, T_K, kTherm_WmK)
 
             # Assign tidal heating function
             # (currently a placeholder)
-            self.Htidal_Wm3 = np.zeros_like(self.kTherm_WmK) + HtidalConst_Wm3  # Placeholder until a self-consistent determination is implemented
+            Htidal_Wm3 = np.zeros_like(kTherm_WmK) + HtidalConst_Wm3  # Placeholder until a self-consistent determination is implemented
             self.fn_Htidal_Wm3 = GetHtidalFunc(HtidalConst_Wm3)
 
             # Assign porosity model function, if applicable
             if Fe_EOS:
-                # No porosity modeled, and no need for dummy field
-                pass
+                # No porosity modeled
+                self.ufn_phi_frac = ReturnZeros(1)
 
             elif porosType is None or porosType == 'none':
                 # No porosity modeled, but need a dummy field for cross-compatibility
-                self.fn_phi_frac = ReturnZeros(1)
+                self.ufn_phi_frac = ReturnZeros(1)
 
             else:
                 if porosType == 'Vitovtova2014' or porosType == 'Chen2020':
@@ -213,8 +224,8 @@ class PerplexEOSStruct:
                     self.PREMlookup = Interp1D(PPREM_MPa, zPREM_km)
                 else:
                     self.PREMlookup = None
-                self.fn_phi_frac = GetphiFunc(self.porosType, self.phiTop_frac, self.Pclosure_MPa,
-                                              self.PREMlookup, self.P_MPa, self.T_K)
+                self.ufn_phi_frac = GetphiFunc(self.porosType, self.phiTop_frac, self.Pclosure_MPa,
+                                              self.PREMlookup, P_MPa, T_K)
 
             # Store complete EOSStruct in global list of loaded EOSs
             EOSlist.loaded[self.EOSlabel] = self
@@ -258,6 +269,52 @@ class PerplexEOSStruct:
         if not self.EXTRAP:
             P_MPa, T_K = ResetNearestExtrap(P_MPa, T_K, self.Pmin, self.Pmax, self.Tmin, self.Tmax)
         return self.ufn_GS_GPa(P_MPa, T_K, grid=grid)
+    def fn_phi_frac(self, P_MPa, T_K, grid=False):
+        if not self.EXTRAP:
+            P_MPa, T_K = ResetNearestExtrap(P_MPa, T_K, self.Pmin, self.Pmax, self.Tmin, self.Tmax)
+        return self.ufn_phi_frac(P_MPa, T_K, grid=grid)
+
+
+class EOSwrapper:
+    """ Lightweight wrapper for accessing EOS functions stored in the EOSlist dict. """
+
+    def __init__(self, key):
+        self.key = key
+        # Assign only those attributes we reference in functions
+        if EOSlist.loaded[self.key].EOStype == 'ice':
+            self.phaseID = EOSlist.loaded[self.key].phaseID
+            self.POROUS = EOSlist.loaded[self.key].POROUS
+        elif EOSlist.loaded[self.key].EOStype == 'ocean':
+            self.Pmax = EOSlist.loaded[self.key].Pmax
+        elif EOSlist.loaded[self.key].EOStype == 'inner':
+            self.comp = EOSlist.loaded[self.key].comp
+
+    def fn_phase(self, P_MPa, T_K):
+        return EOSlist.loaded[self.key].fn_phase(P_MPa, T_K)
+    def fn_rho_kgm3(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_rho_kgm3(P_MPa, T_K, grid=grid)
+    def fn_Cp_JkgK(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_Cp_JkgK(P_MPa, T_K, grid=grid)
+    def fn_alpha_pK(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_alpha_pK(P_MPa, T_K, grid=grid)
+    def fn_kTherm_WmK(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_kTherm_WmK(P_MPa, T_K, grid=grid)
+    def fn_VP_kms(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_VP_kms(P_MPa, T_K, grid=grid)
+    def fn_VS_kms(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_VS_kms(P_MPa, T_K, grid=grid)
+    def fn_KS_GPa(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_KS_GPa(P_MPa, T_K, grid=grid)
+    def fn_GS_GPa(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_GS_GPa(P_MPa, T_K, grid=grid)
+    def fn_phi_frac(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_phi_frac(P_MPa, T_K, grid=grid)
+    def fn_porosCorrect(self, propBulk, propPore, phi, J):
+        return EOSlist.loaded[self.key].fn_porosCorrect(propBulk, propPore, phi, J)
+    def fn_sigma_Sm(self, P_MPa, T_K):
+        return EOSlist.loaded[self.key].fn_sigma_Sm(P_MPa, T_K)
+    def fn_Seismic(self, P_MPa, T_K):
+        return EOSlist.loaded[self.key].fn_Seismic(P_MPa, T_K)
 
 
 def ResetNearestExtrap(var1, var2, min1, max1, min2, max2):
@@ -389,17 +446,25 @@ class GetphiCalc:
     def __init__(self, phiMax_frac, fn_phiEOS_frac, phiMin_frac):
         self.phiMin_frac = phiMin_frac
         self.phiMax_frac = phiMax_frac
-        self.fn_phiEOS_frac = fn_phiEOS_frac
         self.multFactor = 1.0
+        if type(fn_phiEOS_frac(0,0)) == ReturnZeros:
+            # For some reason, binding a ReturnZeros func as a method requires an extra dummy call
+            self.fn_phiEOS_frac = fn_phiEOS_frac(0, 0)
+        else:
+            self.fn_phiEOS_frac = fn_phiEOS_frac
 
     def update(self, newPhiMax_frac):
         self.multFactor = newPhiMax_frac / self.phiMax_frac
 
-    def __call__(self, P_MPa, T_K):
-        phi_frac = self.multFactor * self.fn_phiEOS_frac(P_MPa, T_K, grid=False)
-        if np.size(P_MPa) == 1:
-            if phi_frac < self.phiMin_frac:
-                phi_frac = 0
+    def __call__(self, P_MPa, T_K, grid=False):
+        if type(self.fn_phiEOS_frac) == ReturnZeros:
+            phi_frac = self.fn_phiEOS_frac(P_MPa, T_K, grid=grid)
         else:
-            phi_frac[phi_frac < self.phiMin_frac] = 0
+            phi_frac = self.multFactor * self.fn_phiEOS_frac(P_MPa, T_K, grid=grid)
+            if np.size(P_MPa) == 1:
+                if phi_frac < self.phiMin_frac:
+                    phi_frac = 0
+            else:
+                phi_frac[phi_frac < self.phiMin_frac] = 0
+
         return phi_frac
