@@ -1,10 +1,13 @@
 import numpy as np
-import logging as log
+import logging
 from PlanetProfile.Utilities.defineStructs import Constants
 from seafreeze import seafreeze as SeaFreeze
 from PlanetProfile.Thermodynamics.HydroEOS import PhaseConv, GetTfreeze, GetPfreeze, kThermMelinder2007, \
     kThermHobbs1974, kThermIsobaricAnderssonIbari2005, kThermIsothermalAnderssonIbari2005
 
+# Assign logger
+log = logging.getLogger('PlanetProfile')
+
 def ConvectionDeschampsSotin2001(Ttop_K, rTop_m, kTop_WmK, Tb_K, zb_m, gtop_ms2, Pmid_MPa,
                                  oceanEOS, iceEOS, phaseBot, EQUIL_Q):
     """ Thermodynamics calculations for convection in an ice layer
@@ -79,7 +82,7 @@ def ConvectionDeschampsSotin2001(Ttop_K, rTop_m, kTop_WmK, Tb_K, zb_m, gtop_ms2,
 
     # Get melting temperature for calculating viscosity relative to this temp
     if phaseMid == 1:
-        Tmelt_K = GetTfreeze(oceanEOS, Pmid_MPa, Tconv_K, TfreezeRange_K=273-Tconv_K)
+        Tmelt_K = GetTfreeze(oceanEOS, Pmid_MPa, Tconv_K, TfreezeRange_K=275-Tconv_K)
     else:
         Tmelt_K = GetTfreeze(oceanEOS, Pmid_MPa, Tconv_K)
     etaConv_Pas = Constants.etaMelt_Pas[phaseMid] * np.exp(A * (Tmelt_K/Tconv_K - 1))
