@@ -2,14 +2,18 @@
 
 import os
 import numpy as np
-import logging as log
+import logging
+from collections.abc import Iterable
 from PlanetProfile import _ROOT
-from PlanetProfile.GetConfig import FigMisc
+from PlanetProfile.GetConfig import FigMisc, FigLbl
 from PlanetProfile.Thermodynamics.HydroEOS import GetOceanEOS
 from PlanetProfile.Thermodynamics.InnerEOS import GetInnerEOS
 from PlanetProfile.Utilities.PPversion import ppVerNum, CheckCompat
 from PlanetProfile.Utilities.defineStructs import DataFilesSubstruct, FigureFilesSubstruct, Constants
 
+# Assign logger
+log = logging.getLogger('PlanetProfile')
+
 def SetupInit(Planet, Params):
 
     # Print version number
@@ -20,6 +24,7 @@ def SetupInit(Planet, Params):
     CheckCompat('seafreeze')  # SeaFreeze
     if Planet.Ocean.comp == 'Seawater': CheckCompat('gsw')  # Gibbs Seawater
     if Planet.Do.TAUP_SEISMIC: CheckCompat('obspy')  # TauP (accessed as obspy.taup)
+    if Params.CALC_NEW_INDUCT: CheckCompat('MoonMag')  # MoonMag
 
     # Waterless bodies. We have to do this first, before filename
     # generation, to ensure ocean comp is set.
@@ -161,6 +166,9 @@ def SetupInit(Planet, Params):
         Planet.RaCrit = np.nan
         Planet.RaCritIII = np.nan
         Planet.RaCritV = np.nan
+        Planet.Tconv_K = np.nan
+        Planet.TconvIII_K = np.nan
+        Planet.TconvV_K = np.nan
         Planet.eLid_m = 0.0
         Planet.eLidIII_m = 0.0
         Planet.eLidV_m = 0.0
@@ -177,7 +185,11 @@ def SetupInit(Planet, Params):
         if not Planet.Do.PORE_EOS_DIFFERENT:
             Planet.Sil.PHydroMax_MPa = Planet.Ocean.PHydroMax_MPa
 
-        if Planet.Sil.porosType != 'Han2014':
+        if Planet.Sil.porosType == 'Han2014':
+            if Planet.Sil.phiRockMax_frac is None:
+                log.warning('Sil.phiRockMax_frac is not set. Using arbitrary max porosity of 0.7.')
+                Planet.Sil.phiRockMax_frac = 0.7
+        else:
             Planet.Do.FIXED_POROSITY = True
         if Planet.Sil.phiRangeMult <= 1:
             raise ValueError(f'Sil.phiRangeMult = {Planet.Sil.phiRangeMult}, but it must be greater than 1.')
@@ -208,7 +220,7 @@ def SetupInit(Planet, Params):
     if Planet.Bulk.M_kg is None:
         Planet.Bulk.M_kg = Planet.Bulk.rho_kgm3 * (4/3*np.pi * Planet.Bulk.R_m**3)
     else:
-        if Planet.Bulk.rho_kgm3 is not None:
+        if Planet.Bulk.rho_kgm3 is not None and not Params.DO_EXPLOREOGRAM:
             log.warning('Both bulk mass and density were specified. Only one is required--' +
                         'density will be recalculated from bulk mass for consistency.')
         Planet.Bulk.rho_kgm3 = Planet.Bulk.M_kg / (4/3*np.pi * Planet.Bulk.R_m**3)
@@ -240,20 +252,30 @@ def SetupInit(Planet, Params):
 
             # Make sure Sil.phiRockMax_frac is set in case we're using a porosType that doesn't require it
             if Planet.Sil.phiRockMax_frac is None or Planet.Sil.porosType != 'Han2014':
-                Planet.Sil.phiRockMax_frac = Planet.Sil.EOS.fn_phi_frac(np.zeros(1),np.zeros(1))
+                Planet.Sil.phiRockMax_frac = Planet.Sil.EOS.fn_phi_frac(0, 0)
 
         # Iron core if present
         if Planet.Do.Fe_CORE:
             Planet.Core.EOS = GetInnerEOS(Planet.Core.coreEOS, EOSinterpMethod=Params.lookupInterpMethod, Fe_EOS=True,
                                           kThermConst_WmK=Planet.Core.kTherm_WmK, EXTRAP=Params.EXTRAP_Fe)
 
+    # Ensure ionosphere bounds and conductivity are in a format we expect
+    if Planet.Magnetic.ionosBounds_m is None:
+        Planet.Magnetic.ionosBounds_m = [np.nan]
+    elif not isinstance(Planet.Magnetic.ionosBounds_m, Iterable):
+        Planet.Magnetic.ionosBounds_m = [Planet.Magnetic.ionosBounds_m]
+    if Planet.Magnetic.sigmaIonosPedersen_Sm is None:
+        Planet.Magnetic.sigmaIonosPedersen_Sm = [np.nan]
+    elif not isinstance(Planet.Magnetic.sigmaIonosPedersen_Sm, Iterable):
+        Planet.Magnetic.sigmaIonosPedersen_Sm = [Planet.Magnetic.sigmaIonosPedersen_Sm]
+
     # Preallocate layer physical quantity arrays
     Planet = SetupLayers(Planet)
 
     return Planet, Params
 
 
-def SetupFilenames(Planet, Params):
+def SetupFilenames(Planet, Params, exploreAppend=None, figExploreAppend=None):
     """ Generate filenames for saving data and figures.
     """
     datPath = Planet.bodyname
@@ -278,15 +300,18 @@ def SetupFilenames(Planet, Params):
     label = ''
     if Planet.Do.NO_H2O:
         saveLabel += f'NoH2O_qSurf{Planet.Bulk.qSurf_Wm2*1e3:.1f}mWm2'
-        label += f'$q_\mathrm{{surf}}\,{Planet.Bulk.qSurf_Wm2*1e3:.1f}\,\si{{mW/m^2}}$'
+        setStr = f'$q_\mathrm{{surf}}\,{Planet.Bulk.qSurf_Wm2*FigLbl.qMult:.1f}\,\si{{{FigLbl.fluxUnits}}}$'
+        label += setStr
     else:
         if Planet.Ocean.comp == 'PureH2O':
             saveLabel += f'{Planet.Ocean.comp}_Tb{Planet.Bulk.Tb_K}K'
-            label += f'Pure \ce{{H2O}}, $T_b\,\SI{{{Planet.Bulk.Tb_K}}}{{K}}$'
+            setStr = f'Pure \ce{{H2O}}'
+            label += f'{setStr}, $T_b\,\SI{{{Planet.Bulk.Tb_K}}}{{K}}$'
         else:
             saveLabel += f'{Planet.Ocean.comp}_{Planet.Ocean.wOcean_ppt:.1f}ppt' + \
                         f'_Tb{Planet.Bulk.Tb_K}K'
-            label += f'{Planet.Ocean.wOcean_ppt:.1f}\,ppt \ce{{{Planet.Ocean.comp}}}' + \
+            setStr = f'${Planet.Ocean.wOcean_ppt*FigLbl.wMult:.1f}\,\si{{{FigLbl.wUnits}}}$ \ce{{{Planet.Ocean.comp}}}'
+            label += setStr + \
                 f', $T_b\,\SI{{{Planet.Bulk.Tb_K}}}{{K}}$'
         if Planet.Do.CLATHRATE:
             saveLabel += '_Clathrates'
@@ -300,15 +325,21 @@ def SetupFilenames(Planet, Params):
                 label += f'Pure \ce{{H2O}} pores'
             else:
                 saveLabel += f'_{Planet.Sil.poreComp}_{Planet.Sil.wPore_ppt:.1f}pptPores'
-                label += f', {Planet.Sil.wPore_ppt:.1f}\,ppt \ce{{{Planet.Sil.poreComp}}} pores'
+                label += f', {Planet.Sil.wPore_ppt*FigLbl.wMult:.1f}\,\si{{{FigLbl.wUnits}}} \ce{{{Planet.Sil.poreComp}}} pores'
     if Planet.Sil.mantleEOSName is not None: saveLabel += f'_{Planet.Sil.mantleEOSname}'
 
     Planet.saveLabel = saveLabel
+    Planet.tradeLabel = f'{label}, $C/MR^2\,{Planet.Bulk.Cmeasured}\pm{Planet.Bulk.Cuncertainty}$'
     Planet.label = label
-    inductBase = f'{Planet.name}_{Params.Induct.inductOtype}'
-    DataFiles = DataFilesSubstruct(datPath, saveBase + saveLabel, Planet.Ocean.comp, inductBase=inductBase)
+    if Params.DO_INDUCTOGRAM:
+        inductBase = f'{Planet.name}_{Params.Induct.inductOtype}'
+    else:
+        inductBase = None
+    DataFiles = DataFilesSubstruct(datPath, saveBase + saveLabel, Planet.Ocean.comp, inductBase=inductBase,
+                                   exploreAppend=exploreAppend)
     FigureFiles = FigureFilesSubstruct(figPath, saveBase + saveLabel, FigMisc.xtn,
-                                       comp=Planet.Ocean.comp, inductBase=inductBase)
+                                       comp=Planet.Ocean.comp, inductBase=inductBase,
+                                       exploreAppend=figExploreAppend)
 
     return DataFiles, FigureFiles
 
@@ -320,13 +351,13 @@ def SetupLayers(Planet):
     if not Planet.Do.NO_H2O:
         nOceanMax = int(Planet.Ocean.PHydroMax_MPa / Planet.Ocean.deltaP)
         Planet.Steps.nHydroMax = Planet.Steps.nClath + Planet.Steps.nIceI + Planet.Steps.nIceIIILitho + Planet.Steps.nIceVLitho + nOceanMax
-
+    
     Planet.phase = np.zeros(Planet.Steps.nHydroMax, dtype=np.int_)
     Planet.P_MPa, Planet.T_K, Planet.r_m, Planet.rho_kgm3, \
         Planet.Cp_JkgK, Planet.alpha_pK, Planet.g_ms2, Planet.phi_frac, \
-        Planet.sigma_Sm, Planet.z_m, Planet.MLayer_kg, Planet.kTherm_WmK, \
+        Planet.sigma_Sm, Planet.z_m, Planet.MLayer_kg, Planet.VLayer_m3, Planet.kTherm_WmK, \
         Planet.Htidal_Wm3, Planet.Ppore_MPa, Planet.rhoMatrix_kgm3, Planet.rhoPore_kgm3 = \
-        (np.zeros(Planet.Steps.nHydroMax) for _ in range(16))
+        (np.zeros(Planet.Steps.nHydroMax) for _ in range(17))
 
     # Layer property initialization for surface
     Planet.z_m[0] = 0.0  # Set first layer depth to zero (layer properties correspond to outer radius)
