@@ -336,6 +336,15 @@ class MagneticSubstruct:
         self.mLin = None  # m values corresponding to each n in nLin
         self.BinmLin_nT = None  # Linear form of Binm_nT, with shape (nExc, (nPrmMax+pMax+1)**2 - 1), such that BinmLin[i, j] = Binm[i, int(m[j]<0), n[j], m[j]]
         self.Bi1xyz_nT = {'x': None, 'y': None, 'z': None}  # Induced dipole surface strength in IAU components
+        # Fourier spectrum calculations
+        self.FT_LOADED = False  # Whether Fourier spectrum data has been loaded and calculated
+        self.Be1xyzFT_nT = {'x': None, 'y': None, 'z': None}  # Complex dipole vector components of excitation spectrum
+        self.TexcFT_hr = None  # Evaluation periods for vector components above
+        self.TmaxFT_hr = None  # Cutoff point for evaluation of Fourier spectrum
+        self.extModelFT = None  # External field model used to evaluate Fourier spectrum
+        self.coordTypeFT = None  # Coordinates of vector components for Fourier spectrum
+        self.Ae1FT = None  # Complex amplitude for dipole induced field, for Fourier spectrum
+        self.Bi1xyzFT_nT = {'x': None, 'y': None, 'z': None}  # Complex induced dipole moments in Fourier spectrum
 
 
 """ Main body profile info--settings and variables """
@@ -481,9 +490,11 @@ class DataFilesSubstruct:
         self.fNameInduct = os.path.join(self.inductPath, saveBase)
         self.inductLayersFile = self.fNameInduct + '_inductLayers.txt'
         self.inducedMomentsFile = self.fNameInduct + '_inducedMoments.mat'
-        self.fNameInductOgram = os.path.join(self.path, 'inductionData', inductBase)
+        self.fNameInductOgram = os.path.join(self.inductPath, inductBase)
         self.inductOgramFile = self.fNameInductOgram + f'{comp}_inductOgram.mat'
         self.inductOgramSigmaFile = self.fNameInductOgram + '_sigma_inductOgram.mat'
+        self.BeFTdata = os.path.join('inductionData', 'Be1xyzFTdata.mat')
+        self.FTdata = os.path.join(self.inductPath, 'Bi1xyzFTdata.mat')
 
 
 # Construct filenames for figures etc.
@@ -525,6 +536,7 @@ class FigureFilesSubstruct:
         induct = 'InductOgram'
         sigma = 'InductOgramSigma'
         Bdip = 'Bdip'
+        MagFT = 'MagSpectrum'
         # Construct Figure Filenames
         self.vwedg = self.fName + vwedg + xtn
         self.vpore = self.fName + vpore + xtn
@@ -544,6 +556,7 @@ class FigureFilesSubstruct:
         self.sigma =         {zType: f'{self.fNameInduct}_{sigma}_{zType}{xtn}' for zType in ['Amp', 'Bx', 'By', 'Bz', 'Bcomps']}
         self.sigmaOnly =     {zType: f'{self.fNameInduct}_{sigma}Only_{zType}{xtn}' for zType in ['Amp', 'Bx', 'By', 'Bz', 'Bcomps']}
         self.Bdip =         {axComp: f'{self.fNameInduct}_{Bdip}{axComp}{xtn}' for axComp in ['x', 'y', 'z', 'all']}
+        self.MagFT =                 f'{self.fNameInduct}_{MagFT}{xtn}'
 
 
 """ General parameter options """
@@ -598,17 +611,61 @@ class InductOgramParamsStruct:
         self.oceanInterpMethod = 'linear'  # Interpolation method for determining ocean conductivities when REDUCED_INDUCT is True.
         self.nIntL = 5  # Number of ocean layers to use when REDUCED_INDUCT = 1
 
-        # Plot settings to match inductograms from Vance et al. (2021): https://doi.org/10.1029/2020JE006418
-        self.V2021_D_km = [91, 117, 96, 124,
-                           91, 117, 91, 119]
-        self.V2021_sigma_Sm = [0.4132, 0.4533, 3.3661, 3.7646,
-                               0.3651, 0.3855, 2.8862, 3.0760]
-        self.V2021_faceColors = [None, None, 'b', 'm',
-                                 None, None, 'c', '#b000ff']
-        self.V2021_edgeColors = ['b', 'm', 'k', 'k',
-                                 'c', '#b000ff', 'k', 'k']
-        self.V2021_symbols = ['^', 'v', '^', 'v',
-                              '^', 'v', '^', 'v']
+        # Plot settings to mark on inductograms after Vance et al. (2021): https://doi.org/10.1029/2020JE006418
+        self.V2021_zb_km = {
+            'Europa': np.array([5, 30, 5, 30,
+                                5, 30, 5, 30]),
+            'Ganymede': np.array([25, 92, 25, 92]),
+            'Callisto': np.array([99, 128, 99, 128])
+        }
+        self.V2021_D_km = {
+            'Europa': np.array([117, 91, 124, 96,
+                                117, 91, 119, 91]),
+            'Ganymede': np.array([442, 276, 458, 282]),
+            'Callisto': np.array([132, 21, 130, 21])
+        }
+        self.V2021_sigma_Sm = {
+            'Europa': np.array([0.4533, 0.4132, 3.7646, 3.3661,
+                                0.3855, 0.3651, 3.0760, 2.8862]),
+            'Ganymede': np.array([0.5166, 0.3322, 4.0699, 2.3476]),
+            'Callisto': np.array([0.2307, 0.0895, 1.5256, 0.6025])
+        }
+        self.V2021_comp = {
+            'Europa': np.array(['MgSO4', 'MgSO4', 'MgSO4', 'MgSO4',
+                                'Seawater', 'Seawater', 'Seawater', 'Seawater']),
+            'Ganymede': np.array(['MgSO4', 'MgSO4', 'MgSO4', 'MgSO4']),
+            'Callisto': np.array(['MgSO4', 'MgSO4', 'MgSO4', 'MgSO4'])
+        }
+        self.V2021_w_ppt = {
+            'Europa': np.array([10, 10, 100, 100,
+                                3.5165, 3.5165, 35.165, 35.165]),
+            'Ganymede': np.array([10, 10, 100, 100]),
+            'Callisto': np.array([10, 10, 100, 100])
+        }
+        self.V2021_Tb_K = {
+            'Europa': np.array([273.1, 270.4, 272.7, 269.8,
+                                272.5, 270.0, 270.8, 268.2]),
+            'Ganymede': np.array([270.7, 261.6, 270.2, 260.0]),
+            'Callisto': np.array([257.4, 250.8, 255.7, 250.8])
+        }
+        self.V2021_FC = {
+            'Europa': np.array(['None', 'None', 'm', 'b',
+                                'None', 'None', '#b000ff', 'c']),
+            'Ganymede': np.array(['None', 'None', 'm', 'b']),
+            'Callisto': np.array(['None', 'None', 'm', 'b'])
+        }
+        self.V2021_EC = {
+            'Europa': np.array(['m', 'b', 'k', 'k',
+                                '#b000ff', 'c', 'k', 'k']),
+            'Ganymede': np.array(['m', 'b', 'k', 'k']),
+            'Callisto': np.array(['m', 'b', 'k', 'k'])
+        }
+        self.V2021_MS = {
+            'Europa': np.array(['v', '^', 'v', '^',
+                                'v', '^', 'v', '^']),
+            'Ganymede': np.array(['v', '^', 'v', '^']),
+            'Callisto': np.array(['v', '^', 'v', '^'])
+        }
 
     def GetClevels(self, zName, Tname):
         if self.bodyname is None:
@@ -640,12 +697,13 @@ class ConductLayerParamsStruct:
         self.asymFstring = 'Shape_4piNormDepth'
 
 
-""" Excitation spectrum settings (WIP) """
+""" Excitation spectrum settings """
 class ExcitationSpectrumParamsStruct:
     # Do not set any values below. All values are assigned in PlanetProfile.GetConfig.
     def __init__(self):
         self.nOmegaPts = 100  # Resolution in log frequency space for magnetic excitation spectra
-        self.nOmegaFine = 1000  # Fine-spacing resolution for log frequency spectrum
+        self.interpMethod = 'cubic'  # Interpolation method for complex response amplitudes in Fourier spectrum
+        self.Tmin_hr = None  # Cutoff period in hr to limit Fourier space plots to
 
 
 """ ExploreOgram input parameters struct """
@@ -773,6 +831,11 @@ class ColorStruct:
         # Saturation & color brightness ("value" in HSV) values for salinity/conductivity axis bounds
         self.fresh = [0.5, 1.0]
         self.salty = [1.0, 0.5]
+        
+        # Fourier spectrum plots
+        self.BeiFT = {'x': None, 'y': None, 'z': None}
+        self.Ae1FT = None
+        self.TexcFT = None
 
 
     def SetCmaps(self):
@@ -880,6 +943,12 @@ class StyleStruct:
         self.MAlims = None  # Alpha channel (opacity) limits for markers 
         self.LS_BdipInset = '-'  # Linestyle for inset box 
         self.LW_BdipInset = 0.5  # Linewidth for inset box
+        
+        # Fourier spectrum plots
+        self.LS_FT = None  # Linestyle of Fourier spectrum plots
+        self.LW_FT = None  # Linewidth for Ae1, Bx, By, Bz in Fourier spectrum plots
+        self.LWTexc_FT = None  # Linewidth for optional lines marking dominant excitations in Ae1 plot
+        
 
     def GetLW(self, wOcean_ppt, wMinMax_ppt):
         linewidth = interp1d(wMinMax_ppt, self.LWlims,
@@ -978,6 +1047,17 @@ class FigLblStruct:
         self.ionosTopLabel = r'Ionosphere maximum altitude ($\si{km}$)'
         self.silPclosureLabel = r'Silicate pore closure pressure ($\si{MPa}$)'
         self.icePclosureLabel = r'Ice pore closure pressure ($\si{MPa}$)'
+        
+        # Magnetic excitation spectrum labels
+        self.MagFTtitle = r'magnetic Fourier spectra'
+        self.TexcLabel = r'Excitation period $T_\mathrm{exc}$ ($\si{hr}$)'
+        self.fExcLabel = r'Excitation frequency $f_\mathrm{exc}$ ($\si{Hz}$)'
+        self.BeFTtitle = r'Excitation amplitude'
+        self.BeFTlabel = r'$|B^e_{x,y,z}|$ ($\si{nT}$)'
+        self.Ae1FTtitle = r'Dipolar complex response amplitude'
+        self.Ae1FTlabel = r'$|\mathcal{A}^e_1|$'
+        self.BiFTtitle = r'Induced dipole surface strength'
+        self.BiFTlabel = r'$|B^i_{x,y,z}|$ ($\si{nT}$)'
 
         # Induction parameter-dependent settings
         self.phaseSpaceTitle = None
@@ -1307,6 +1387,7 @@ class FigSizeStruct:
         self.BdipCombo = None
         self.BdipSolo = None
         self.BdipSoloCombo = None
+        self.MagFT = None
 
 
 """ Miscellaneous figure options """
